#
# spec file for package sdbootutil
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
Name:           sdbootutil
Version:        1+git20250722.bf18f3b
Release:        1.1
Summary:        bootctl wrapper for BLS boot loaders
License:        MIT
URL:            https://github.com/openSUSE/sdbootutil
Source:         %{name}-%{version}.tar
Source1:        vendor.tar.zst
Source2:        config.toml
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  libopenssl-devel
BuildRequires:  systemd-rpm-macros
Requires:       %{name}-dracut-measure-pcr
Requires:       dialog
Requires:       dracut-pcr-signature
Requires:       efibootmgr
Requires:       jq
Requires:       keyutils
Requires:       openssl
Requires:       pcr-oracle
Requires:       qrencode
Requires:       sed
Requires:       (%{name}-snapper if (snapper and btrfsprogs))
Requires:       (%{name}-tukit if read-only-root-fs)
# While systemd-pcrlock is in experimental
Requires:       systemd-experimental
# something needs to require it. Can be us.
Requires:       tpm2.0-tools
# While bootctl is in udev
Requires:       udev
Supplements:    (grub2-x86_64-efi-bls and shim)
Supplements:    (systemd-boot and shim)
# Because uhmac it is not a noarch package
# BuildArch:      noarch
ExclusiveArch:  aarch64 riscv64 x86_64
%{?systemd_requires}

%description
bootctl wrapper for BLS boot loaders, like systemd-boot and grub2-bls.
Implements also the life cycle of a full disk encryption installation,
based on systemd.

%package snapper
Summary:        plugin script for snapper
Requires:       %{name} = %{version}
Requires:       btrfsprogs
Requires:       snapper
BuildArch:      noarch

%description snapper
Plugin scripts for snapper to handle BLS config files

%package tukit
Summary:        plugin script for tukit
Requires:       %{name} = %{version}
Requires:       tukit
BuildArch:      noarch

%description tukit
Plugin scripts for tukit to handle BLS config files

%package kernel-install
Summary:        Hook script for kernel-install
Requires:       %{name} = %{version}
# While kernel-install is in udev
Requires:       udev
BuildArch:      noarch

%description kernel-install
Plugin script for kernel-install. Note: installation of this
package may disable other plugin scripts that are incompatible.

%package enroll
Summary:        Full disk encryption enrollment
Requires:       %{name} = %{version}
BuildArch:      noarch

%description enroll
Systemd service and script for full disk encryption enrollment.

%package jeos-firstboot-enroll
Summary:        JEOS module for full disk encryption enrollment
Requires:       %{name} = %{version}
Requires:       %{name}-enroll = %{version}
Requires:       jeos-firstboot
BuildArch:      noarch

%description jeos-firstboot-enroll
JEOS module for full disk encryption enrollment. The module
present the different options and delegate into sdbootutil-enroll
service the effective enrollment.

%package bash-completion
Summary:        Bash completions for sdbootutil
Requires:       %{name} = %{version}
Requires:       bash
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash completions script for sdbootutil.
Allows the user to press TAB to see available commands,
options and parameters.

%package dracut-measure-pcr
Summary:        Dracut module to measure PCR 15
BuildRequires:  pkgconfig
BuildRequires:  rpm-config-SUSE
BuildRequires:  pkgconfig(dracut)
BuildArch:      noarch

%description dracut-measure-pcr
Dracut module from sdbootutil to measure PCR 15 in non-UKIs systems

%prep
%autosetup -a1 -p1
mv vendor uhmac
cd uhmac
mkdir .cargo
install -D -m 644 %{SOURCE2} .cargo/config.toml

%build
cd uhmac
%{cargo_build}

%install
install -D -m 755 %{name} %{buildroot}%{_bindir}/%{name}

# Install uhmac binary
pushd uhmac
%{cargo_install}
install -D -m 755 %{buildroot}%{_bindir}/uhmac %{buildroot}%{_libexecdir}/%{name}/uhmac
rm %{buildroot}%{_bindir}/uhmac
popd

# Update prediction service
install -D -m 644 %{name}-update-predictions.service \
	%{buildroot}%{_unitdir}/%{name}-update-predictions.service

# Enrollment service
install -m 755 %{name}-enroll %{buildroot}%{_bindir}/%{name}-enroll
install -D -m 644 %{name}-enroll.service %{buildroot}/%{_unitdir}/%{name}-enroll.service

# Jeos module
install -D -m 644 jeos-firstboot-enroll-override.conf \
	%{buildroot}%{_prefix}/lib/systemd/system/jeos-firstboot.service.d/jeos-firstboot-enroll-override.conf
install -D -m 644 jeos-firstboot-enroll %{buildroot}%{_datadir}/jeos-firstboot/modules/enroll

# Snapper
install -D -m 755 10-%{name}.snapper %{buildroot}%{_prefix}/lib/snapper/plugins/10-%{name}.snapper

# Tukit
install -D -m 755 10-%{name}.tukit %{buildroot}%{_prefix}/lib/tukit/plugins/10-%{name}.tukit

# kernel-install
install -D -m 755 50-%{name}.install %{buildroot}%{_prefix}/lib/kernel/install.d/50-%{name}.install

# Bash completions
install -D -m 755 completions/bash_sdbootutil %{buildroot}%{_datadir}/bash-completion/completions/sdbootutil

# Dracut module
install -D -m 755 module-setup.sh %{buildroot}%{_prefix}/lib/dracut/modules.d/50measure-pcr/module-setup.sh
install -D -m 755 measure-pcr-generator.sh %{buildroot}%{_prefix}/lib/dracut/modules.d/50measure-pcr/measure-pcr-generator.sh
install -D -m 755 measure-pcr-validator.sh %{buildroot}%{_prefix}/lib/dracut/modules.d/50measure-pcr/measure-pcr-validator.sh
install -D -m 644 measure-pcr-validator.service %{buildroot}/%{_prefix}/lib/dracut/modules.d/50measure-pcr/measure-pcr-validator.service

install -d -m 700 %{buildroot}%{_sharedstatedir}/%{name}

# tmpfiles
install -D -m 755 kernel-install-%{name}.conf \
	%{buildroot}%{_prefix}/lib/tmpfiles.d/kernel-install-%{name}.conf

%transfiletriggerin -- %{_prefix}/lib/systemd/boot/efi %{_datadir}/grub2/%{_build_arch}-efi %{_datadir}/efi/%{_build_arch}
cat > /dev/null || :
[ "$YAST_IS_RUNNING" != 'instsys' ] || exit 0
[ -e /sys/firmware/efi/efivars ] || exit 0
[ -z "$TRANSACTIONAL_UPDATE" ] || exit 0
[ -z "$VERBOSE_FILETRIGGERS" ] || echo "%{name}-%{version}-%{release}: updating bootloader"
if [ -e /etc/sysconfig/bootloader ]; then
	. /etc/sysconfig/bootloader &> /dev/null
	if [ "$LOADER_TYPE" = "grub2-bls" ] || [ "$LOADER_TYPE" = "systemd-boot" ]; then
		sdbootutil update
	fi
else
	sdbootutil update
fi

%preun
%service_del_preun %{name}-update-predictions.service

%postun
%service_del_postun %{name}-update-predictions.service

%pre
%service_add_pre %{name}-update-predictions.service

%post
%service_add_post %{name}-update-predictions.service

%preun enroll
%service_del_preun %{name}-enroll.service

%postun enroll
%service_del_postun %{name}-enroll.service

%pre enroll
%service_add_pre %{name}-enroll.service

%post enroll
%service_add_post %{name}-enroll.service

%posttrans kernel-install
%tmpfiles_create kernel-install-%{name}.conf

%post dracut-measure-pcr
%{?regenerate_initrd_post}

%posttrans dracut-measure-pcr
%{?regenerate_initrd_posttrans}

%postun dracut-measure-pcr
%{?regenerate_initrd_post}

%files
%license LICENSE
%dir %{_sharedstatedir}/%{name}
%{_bindir}/%{name}
%{_unitdir}/%{name}-update-predictions.service
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/uhmac

%files snapper
%dir %{_prefix}/lib/snapper
%dir %{_prefix}/lib/snapper/plugins
%{_prefix}/lib/snapper/plugins/*

%files tukit
%dir %{_prefix}/lib/tukit
%dir %{_prefix}/lib/tukit/plugins
%{_prefix}/lib/tukit/plugins/*

%files kernel-install
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/*
%{_prefix}/lib/tmpfiles.d/kernel-install-%{name}.conf

%files enroll
%{_bindir}/%{name}-enroll
%{_unitdir}/%{name}-enroll.service

%files jeos-firstboot-enroll
%dir %{_datadir}/jeos-firstboot
%dir %{_datadir}/jeos-firstboot/modules
%{_datadir}/jeos-firstboot/modules/enroll
%dir %{_unitdir}/jeos-firstboot.service.d
%{_unitdir}/jeos-firstboot.service.d/jeos-firstboot-enroll-override.conf

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/sdbootutil

%files dracut-measure-pcr
%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%{_prefix}/lib/dracut/modules.d/50measure-pcr

%changelog
* Tue Jul 22 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250722.bf18f3b:
  * Measure kernel in PCR4 for grub2-bls if secure-boot
* Fri Jul 18 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250718.9f557f7:
  * MicroOS mounts encrypted /var in initrd
* Wed Jul 16 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250716.b03c12f:
  * Revert "Check for transactional systems by actually checking ro status, not mount attributes"
* Mon Jul 14 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250710.d8e5d82:
  * Check for transactional systems by actually checking ro status, not mount attributes
* Fri Jun 13 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250613.ee73e55:
  * Fix uhmac installation
  * Remove edition downgrade
  * Update Cargo.lock
* Thu May 29 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250529.307d6ff:
  * Remove noarch for main package
  * Copy measure-pcr-prediction if missing in ESP
  * Compile and install uhmac
  * Use uhmac instead of openssl for HMAC
  * uhmac: add Rust tool for HMAC
  * Re-enable riscv64 arch
  * Support non-secure boot installations
  * Rework removable media detection
  * jeos-firstboot-enroll: fix typo in msgbox
  * Measure GPT of the disk with ESP, not the disk with root
  * jeos-firstboot-enroll: show final error message
* Mon May  5 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250505.f4890e9:
  * Build only for Intel and arm (bsc#1242256)
* Wed Apr 30 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250430.f7d1ad1:
  * Update DA lockout message
  * jeos-firstboot-enroll: show errors as dialog
* Fri Apr 25 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250425.25d659b:
  * get-timeout for sd-boot return unsigned value
  * jeos-firstboot-enroll: drop unused variable
  * jeos-firstboot-enroll: continue if no enrollment (bsc#1236583)
  * jeos-firstboot-enroll: hide keyctl output
  * jeos-firstboot-enroll: add title and description
* Wed Apr 23 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250423.61ca94f:
  * Revert "Use filesystem order in grub2-bls" (bsc#1241046)
* Wed Apr 23 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250423.7e34390:
  * Check if TPM2 is in lockout (bsc#1241168)
  * Retry password when mismatch
* Mon Apr 21 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250421.7ffd25a:
  * Report when PCR 15 cannot be predicted
  * Reap failed keys
  * Improve asking passwords (bsc#1241171)
* Thu Apr 10 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250410.9086124:
  * Simplify code calling mount_chroot
  * Support transactional systems without overlayfs on /etc
  * Remove unnecessary umount_etc
* Wed Apr  9 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250409.7ec17ae:
  * Call cleanup when snapshots change (boo#1240932)
  * Add cleanup command to drop broken boot entries
  * Document --all parameter
  * Sync the bootloader also in MicroOS
* Mon Apr  7 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250407.f84e1da:
  * Drop PCR2 if in virtual machine
  * Add have_slot function
  * Get boot time from /proc/stat (boo#1240851)
* Fri Apr  4 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250404.f9b9576:
  * Check free space early
  * Add kernel version in title if grub2-bls
* Fri Apr  4 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250404.20a1dfb:
  * Limit 640 to 4 variations
  * Fix get_default for grub2-bls
* Thu Apr  3 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250403.0ae7eeb:
  * Drop shifted variations before the new one
  * Create loader.conf if missing
* Tue Apr  1 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250401.2eda714:
  * Shift only the matching component
  * Rework free-space allocator algorithm
  * Clarify when the initrd is generated
  * Add the kernel version for measurement order
  * Keep original prediction for pcrlock aligment
  * Check array size for emptiness
  * Refactor debug output
  * Reclaim free space when updating entries
  * spec: Update bootloader if it is recognized
  * Limit variations up to 8 for a component
  * Add priority field in entry list
  * Make snapshot_ids ordered by importance
  * Convert echo to info
  * In virtual environment drop PCR0
* Fri Mar 28 2025 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 1+git20250328.f1d4885:
  * Fallback to file config when bootctl fails
  * Remove TODO file
  * Declare local variable
  * Print colors when in terminal
  * Do not load the config file when variable is set
  * Uset btrfs instead of snapper for set default snapshot
  * Drop unused entries parameter
  * Improve boot loader detection
* Thu Mar 27 2025 aplanas@suse.com
- Update to version 1+git20250327.9714cbd:
  * Get boot_dst from os-release NAME
  * Add --devices parameter
* Mon Mar 24 2025 aplanas@suse.com
- Update to version 1+git20250324.c1cd393:
  * Use filesystem order in grub2-bls
* Mon Mar 17 2025 aplanas@suse.com
- Update to version 1+git20250311.8d3db8b:
  * Load the config file when updating the predictions
  * Include swap partitions for PCR15
  * Soft fails keyctl setperm when called via YaST
  * Revoke cryptenroll key if is incorrect
* Fri Mar  7 2025 aplanas@suse.com
- Update to version 1+git20250307.d46fcde:
  * Add fallback logic when generatic predictions
  * Don't use sdbootutil-pin when reading vk
  * Drop parameters for generate_tpm2_predictions
  * Fix style
  * Fix --signed-policy parameter
* Thu Mar  6 2025 aplanas@suse.com
- Update to version 1+git20250306.0811984:
  * Fix list of tracked devices
  * Don't echo '\n' when timeout or default entry are empty
* Wed Mar  5 2025 aplanas@suse.com
- Update to version 1+git20250305.278a563:
  * Revert "Remove .conf suffix from grubenv (bsc#1237198)"
  * Drop unused parentheses
  * Fix name of local variable
* Tue Mar  4 2025 aplanas@suse.com
- Update to version 1+git20250304.16b1e1b:
  * Fix location of initial boot entries
  * Set keyslot as local
  * Style changes
* Mon Mar  3 2025 aplanas@suse.com
- Update to version 1+git20250303.63ae770:
  * Fix typo in comment
  * Fix openssl -noout call
  * Store the password in cryptenroll keyring
* Mon Mar  3 2025 aplanas@suse.com
- Update to version 1+git20250303.11b90a2:
  * Validate the ESP mount point
  * Do not recurse when called from snapper
* Thu Feb 27 2025 aplanas@suse.com
- Update to version 1+git20250227.9d0f768:
  * Make set-default-snapshot consistend
* Thu Feb 27 2025 aplanas@suse.com
- Update to version 1+git20250227.0f0a096:
  * Fix typo in variable name
  * Update help entries
  * Fix wrong comparison
* Thu Feb 27 2025 aplanas@suse.com
- Update to version 1+git20250227.da22e9b:
  * Measure all boot entries in grub2-bls
  * Drop wrong comment
  * Validate set-default parameter
  * Quiet openssl when gnerating RSA key
* Tue Feb 25 2025 aplanas@suse.com
- Update to version 1+git20250225.b78f812:
  * Use also cryptenroll key to recover the volume key
* Tue Feb 25 2025 aplanas@suse.com
- Update to version 1+git20250225.292283f:
  * Support UUID references in crypttab
* Mon Feb 24 2025 aplanas@suse.com
- Update to version 1+git20250224.c9be3b6:
  * Do not use && when copying signature (bsc#1237505)
* Fri Feb 21 2025 aplanas@suse.com
- Update to version 1+git20250221.19f7d1a:
  * Reformat the spec file
  * Rework keyctl calls to keep the session keyring
* Wed Feb 19 2025 aplanas@suse.com
- Update to version 1+git20250219.a796c24:
  * generator: exit if /etc/crypttab is missing
  * Fix measure-pcr-validator StandardOutput
* Mon Feb 17 2025 aplanas@suse.com
- Update to version 1+git20250217.f216443:
  * Remove .conf suffix from grubenv (bsc#1237198)
* Fri Feb 14 2025 aplanas@suse.com
- Update to version 1+git20250214.ef3b642:
  * Add banner reporting PCR 15 mismatch
  * Generate PCR 15 predictions if crypttab changed
  * Create predictions for PCR 15
  * Add measure-pcr-validator service
  * Order devices when FIDO2 keys are used
  * Set BuildArch to noarch
  * Add dracut measure-pcr module with generator
  * Add tpm2-pcr-measure crypttab parameter
  * Fix help indentation
* Mon Feb 10 2025 aplanas@suse.com
- Update to version 1+git20250210.45458c4:
  * Requires keyutils (bsc#1236940)
* Thu Jan 30 2025 aplanas@suse.com
- Update to version 1+git20250130.2bcbf46:
  * Recognize set-timeout -1 in systemd-boot (bsc#1236578)
  * Drop unused parameters
  * Remove interactive leftover
  * Add bash completions
  * Export options definition to function
  * Export command definition to function
  * Export bootctl evaluation to function
  * export image name setting to function
  * Remove UI command help
  * Mount devices and subvolumes for chroot
  * Set permission for new keys
  * Regenerate initrd if missing
  * Remove old initrd
  * Accept spaces or tabs when parsing crypttab
  * add info to --help about how to ignore devices
  * Do not include command line parameters before initrd= and
    BOOT_IMAGE= This is necessary because the kernel can inject
    command line options that are placed in front of these
    parameters. sdbootutil then picks these up on the next run and
    causes duplication of them, as the kernel will again inject the
    option. Now sdbootutil ignores these injected parameters.
  * Do not fail if the parent is missing
  * Drop extra echo
  * Fix 'if' expression
  * Fix enrollment method variable
  * Drop unused variables for TUI
  * Remove TUI components
  * Add --removable as alias for --portable
  * Show dracut output in verbose mode
  * Make if-else case statement
  * Add --pcr cli option
* Tue Dec 17 2024 aplanas@suse.com
- Update to version 1+git20241217.5aeb4e9:
  * Use only the first output line of findmount in free space calc
* Tue Dec 17 2024 aplanas@suse.com
- Update to version 1+git20241217.1370153:
  * Add trigger for grub2-bls
* Fri Dec  6 2024 aplanas@suse.com
- Update to version 1+git20241206.dccea55:
  * Fix quotes in bind mount command (bsc#1233378)
  * Allow multiple entries for initial measurements
* Tue Nov 26 2024 aplanas@suse.com
- Update to version 1+git20241126.83ebe2c:
  * Fix help for get-timeout
  * Add get default and timeout
  * Replace -a with &&
  * Drop PATH field
  * sdbootutil-enroll: harden script against unexpected conditions
* Mon Nov 18 2024 aplanas@suse.com
- Update to version 1+git20241118.23c1900:
  * Fix missing grep file
  * Detect new bootctl error message
  * If BLI is not active use the loader.conf
* Tue Nov 12 2024 aplanas@suse.com
- Update to version 1+git20241112.ecf5f97:
  * Move enrollment from disk-encryption-tool
  * Use [/usr]/etc/default/fde-tools as config file
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.6f81ff3:
  * Add list-devices command
  * Ignore devices with x-sdbootutil.ignore mark
  * Quote variable expansion
  * Support empty crypttab options
* Thu Nov  7 2024 aplanas@suse.com
- Update to version 1+git20241107.542aa84:
  * Fix missing timeout parameter
* Tue Nov  5 2024 aplanas@suse.com
- Update to version 1+git20241105.3404bf8:
  * Do a cleanup before making free space
  * Simplify unlock mechanism and recovery key enroll
  * Drop generate-pin parameter
  * Indentation and comments fix
  * Measure grubenv
  * Add set-default and set-timout commands
  * rollback bootloader after setting default snapshot
  * Improve error checking and fix small bugs
  * Add --unlock argument
  * Use unique names for the kernel keyring
  * Add --generate-pin to generate a recovery PIN
  * Enroll a new recovery key
  * Bind mount snapshot dir onto itself before chroot.
* Thu Oct 17 2024 aplanas@suse.com
- Update to version 1+git20241017.34ee974:
  * Keep SELinux label of /etc/crypttab intact when changing options
    (boo#1231696)
  * Fix typo in update-entry help, should be  /etc/kernel/cmdline
* Tue Oct  8 2024 aplanas@suse.com
- Update to version 1+git20241008.3df16d2:
  * Improve not found bootloader error msg
* Mon Oct  7 2024 aplanas@suse.com
- Update to version 1+git20241007.192698c:
  * Translate GRUB2 architecture name
* Fri Oct  4 2024 aplanas@suse.com
- Update to version 1+git20241004.a1bb60f:
  * Support bootloader switch
  * Update order after bootloader install
  * Use /etc/sysconfig/bootloader to untie detection
  * Reference to grub2-bls
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7da4a47:
  * Do not specify bootloader requirement
* Wed Oct  2 2024 aplanas@suse.com
- Update to version 1+git20241002.7b8957c:
  * Requires udev for bootctl
  * Use chroot instead of --sysroot in dracut
  * Replace cut with idiomatic code
  * Show recovery PIN generated by systemd-pcrlock
* Thu Sep 12 2024 aplanas@suse.com
- Update to version 1+git20240912.02d30ed:
  * Generate predictions for update_entry
* Thu Sep  5 2024 aplanas@suse.com
- Update to version 1+git20240905.e7ca8cf:
  * Replace root=UUID= with root=device
* Tue Sep  3 2024 aplanas@suse.com
- Update to version 1+git20240903.81f1f40:
  * Generate new predictions for update_all_entries
  * Use raw option in jq update all entries
* Fri Aug 30 2024 aplanas@suse.com
- Update to version 1+git20240830.7f696c8:
  * Use parameter "snapshot" instead the global one
  * Add update-entry and update-all-entries commands
  * Generate tpm2 public key before enroll_pcroracle
  * Fix function names for enrolling pcr-oracle
  * Check if enroll functions worked correctly
  * Warn when pcrlock.json or tpm2-pcr-signature.json are missing
* Thu Aug 29 2024 aplanas@suse.com
- Update to version 1+git20240829.1b5aa4d:
  * Add --default-snapshot parameter (bsc#1224773)
* Fri Aug 23 2024 aplanas@suse.com
- Update to version 1+git20240823.30ef4f1:
  * Remove the executed line in grub2bls
  * Support new grub2-bls package
* Thu Aug 22 2024 aplanas@suse.com
- Update to version 1+git20240822.bc7e06b:
  * Hide exit code for set-default-snapshot plugin call
* Mon Aug 12 2024 aplanas@suse.com
- Update to version 1+git20240812.ee2298f:
  * Use arg_no_reuse_initrd as update_initrd
  * Reorder PIN and PW search
  * fix portable installation The fallback.efi should not be added when installing in portable mode
  * Use /run for tmpfiles instead of /etc
* Mon Jul 22 2024 aplanas@suse.com
- Update to version 1+git20240722.e6d7c91:
  * Fix early return value when cleaning pcrlock.d
* Fri Jul 19 2024 aplanas@suse.com
- Update to version 1+git20240719.36c650f:
  * Remove pcrlock.d if there are too many files
  * Limit LAST_WORKING_SNAPSHOTS to 3
* Thu Jul 18 2024 aplanas@suse.com
- Update to version 1+git20240718.6fbaad1:
  * Enroll using pcr_oracle if pcrlock fails
  * Fix loader.conf measurement
  * Address some shellcheck issues
  * Implement basic [un]enroll commands
  * snapper: do not error if sdbootutil fails
* Tue Jul 16 2024 aplanas@suse.com
- Update to version 1+git20240716.bb40c38:
  * Add --only-default option for list-entries command
  * Turn off colors when the shell it not interactive
  * Support portable installation of bootloader This is useful to create portable drives, so the bootloader entry isn't created permenantly.
* Thu Jul  4 2024 aplanas@suse.com
- Update to version 1+git20240704.a2c5a26:
  * Complain if fde-tools is missing
  * Remove rpm scriptlets
  * Remove is_transactional check
  * Call regenerate-initrd-posttrans
  * Remove pcrlock files older than 1 week
  * Measure initial state from backup
  * Remove useless TODO comments
  * Rename variable to SDB_ADD_INITIAL_COMPONENT
  * Fix transactional check
  * Add system / snapper as prefix for tw/grub2-bls
  * Compose the entry file name in a single place
  * Make 'invert' a generic case
  * Make free space for new kernel / initrd
  * Replace match with test in jq
  * grub: add grub drive in initrd path
  * grub: blscfg is included in the image
  * Fix pcrlock_manual_raw call
  * Add emacs .dir-locals.el
  * Show success message
  * Use a recovery pin for re-enrollment
  * grub2: entries predictions as a single component
  * grub2: remove duplicate function
  * Add blscfg.mod in the ESP and update predictions
  * grub2: generate pcrlock predictions
  * Fix some typos
* Tue May 14 2024 lnussel@suse.com
- Update to version 1+git20240514.56dc89c:
  * Add show-entry command
  * Add SYSTEMD_COLORS flag
  * Add byte order mark to boot.csv
* Mon May  6 2024 lnussel@suse.com
- Update to version 1+git20240506.573a6a4:
  * Don't try to mess with overlayfs inside transaction
  * .spec - requires: dialog
* Wed Apr 10 2024 lnussel@suse.com
- Update to version 1+git20240410.3325802:
  * fallback for machine-id
* Mon Apr  8 2024 lnussel@suse.com
- Update to version 1+git20240408.49e4021:
  * Update requirements
  * Measure manually initrd if pcrlock fails
  * Set SYSTEMD_LOG_LEVEL if verbose
  * Only error out on empty machine-id when actually used
  * feat: add basic boot assessment
  * fix: use new os-release and machine-id files
  * dracut call: --add-device belongs to --sysroot
  * Make sdbootutil usable with no snapshot Systems
* Thu Mar 21 2024 lnussel@suse.com
- Update to version 1+git20240321.04bfbac:
  * Warning if make-policy do not register all PCRs
* Wed Mar 20 2024 lnussel@suse.com
- Update to version 1+git20240320.8b35615:
  * Revert "Remove GRUB2 package conflict"
* Thu Mar 14 2024 lnussel@suse.com
- Update to version 1+git20240314.3472899:
  * Add minimal grub configuration
  * Add systemd.machine_id to kernel command line
  * Add SNAPSHOT parameter to bootloader command
  * Remove GRUB2 package conflict
  * Resolve some shellcheck issues
  * Remove unused variable
  * Change tempfile name
  * needs-update and update meets grub2
  * Consider grub2 when installing the bootloader
  * Add grub2 detector and command
  * fix: delete correct initrd file after installation
  * feat: add add-all-kernels-clean function
  * refactor: use snapshot as argument for all commands
  * Set SYSTEMD_LOG_LEVEL=warning for pcrlock
  * Don't require /etc/sysconfig/fde-tools for pcr-oracle
  * add loader.conf to locking
  * Make sure there are actually entries
  * Prefer pcr-oracle if it's actually configured
  * Don't log to syslog ourselves
  * Fix typo
  * fix: remove Tumbleweed version from regular entries
* Thu Feb 15 2024 lnussel@suse.com
- Update to version 1+git20240215.cb7e392:
  * Add --no-random-seed argument
* Wed Feb 14 2024 lnussel@suse.com
- Update to version 1+git20240214.ba81e0e:
  * Fix pcr-oracle use
  * Add device when generating initrd for snapshots
  * Use systemd-pcrlock
  * Pre-built initrd support
  * Add subvolumes_prefix support
* Tue Jan 23 2024 lnussel@suse.com
- Update to version 1+git20240122.c0d8f76:
  * Integrate with kernel-install
  * Rework kernel listing a bit
  * Add checks to list-entries
  * List entries for current system only by default
  * Fall back to loader.conf if setting efivar failed
  * Runtime determine kernel image name
  * Add list-snapshots
  * Add list-entries command
* Mon Jan 22 2024 lnussel@suse.com
- Update to version 1+git20240118.7e744b4:
  * Bind mount /etc inside the snapshot
* Thu Dec 21 2023 lnussel@suse.com
- Update to version 1+git20231221.42797ab:
  * Do not fail if LUKS2 section is empty
* Thu Dec 14 2023 lnussel@suse.com
- Update to version 1+git20231214.b186b2d:
  * Fix exit code
  * Revert "Add pcr predictions to initrd for now"
* Wed Dec 13 2023 lnussel@suse.com
- Update to version 1+git20231213.2a07af6:
  * Add update-predictions command
  * Predict all the entries
* Mon Dec 11 2023 lnussel@suse.com
- Update to version 1+git20231211.01c6a76:
  * Add ExclusiveArch for 64-bit EFI architectures
* Wed Nov 29 2023 lnussel@suse.com
- Update to version 1+git20231129.d7f3909:
  * Add pcr predictions to initrd for now
  * Generate new TPM2 predictions with pcr-oracle
  * Update file triggers
  * Fix exit code of update command
  * Add a %%transfiletriggerin to update EFI binaries
  * Update help text
* Tue Nov 14 2023 lnussel@suse.com
- Update to version 1+git20231114.6bcf1d3:
  * Fix quoting when calling dracut
* Thu Nov  2 2023 lnussel@suse.de
- Update to version 1+git20231102.beb4c19:
  * Update sdboot in snapper hook
  * Install command with specific snapshot
  * Install sdbootutil marker next to loader
  * In t-u mode, don't call sdbootutil in rpm scriptlets
* Thu Oct 26 2023 lnussel@suse.com
- Update to version 1+git20231026.f43c33c:
  * Fix generating initrd for random snapshots
* Mon Oct 23 2023 lnussel@suse.de
- Update to version 1+git20231023.873adb9:
  * Use correct image name on aarch64
* Thu Oct 19 2023 Fabian Vogt <fvogt@suse.de>
- Add changes from gh#openSUSE/sdbootutil#21:
  * sdbootutil.spec: Add missing efibootmgr dependency
  * sdbootutil.spec: Make sdbootutil-snapper a hard dependency
* Thu Oct 12 2023 lnussel@suse.de
- Update to version 1+git20231005.890f70c:
  * Add --no-reuse-initrd option
  * Refactor boot descriptive entries
  * feat: more descriptive bootmenu entries
  * Remove stray set -x
  * speed up snapper list
  * Fix misleading comment
  * Fix helptext
* Thu Aug 17 2023 lnussel@suse.de
- Update to version 1+git20230817.2a3cd34:
  * Ignore errors from efibootmgr
  * Update spec file
  * Add marker to flag installation using sdbootutil
  * Refactor and fix boot entry installation
  * Don't exit in warn()
  * feat: use arg_esp_path directly
  * fix: get esp_device from bootctl
  * fix: only install shim for secure boot
  * feat: create only non-existing entries & pass correct ESP partition
  * fix: make efibootmgr silent
  * feat: create boot menu entries when installed
* Mon Aug 14 2023 lnussel@suse.com
- Update to version 1+git20230814.38973c7:
  * Support purge-kernels
  * Fix postun
  * Remove debug logging
* Mon Aug  7 2023 Fabian Vogt <fvogt@suse.com>
- Only install the snapper plugin if sdbootutil is requested
- Bypass git, owner is not available ATM
* Thu Jul 27 2023 lnussel@suse.com
- Update to version 1+git20230727.a0e666f:
  * Set and honor $SYSTEMD_ESP_PATH
  * rpm-script: don't remove kernel on reinstalls
* Wed Jul 26 2023 lnussel@suse.com
- Update to version 1+git20230726.a994d2e:
  * Fix installing extra kernels in MicroOS
  * Replace file triggers with scriptlet
  * Fix cleanup of rollback files
  * Don't install unchanged files
  * Add is-bootable and list-kernels commands
  * Add ARCHITECTURE.md which explains how the setup works
  * Add default loader config when installed
* Mon Jul 17 2023 lnussel@suse.com
- Update to version 1+git20230717.dac075e:
  * Install default boot loader in non-secure-boot case too
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.df6eaca:
  * Update features
  * Call stty only in interactive mode
  * silence stty errors
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.356f0c5:
  * Fix rpm dependencies
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230711.f5c7e48:
  * Fix setting root and rootflags
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230626.1ef6b4d:
  * creating /etc/kernel directory
  * Update help screen
* Thu Jun 15 2023 lnussel@suse.de
- Update to version 1+git20230615.587e134:
  * Handle out of space
* Thu Jun 15 2023 Ludwig Nussel <lnussel@suse.de>
- initial package
